<?php

/**
 * @package CsvImporterPlusforACF
 * CSV Upload Form
 */
?>

<?php

use CIPFA\base\CIPFA_BaseController;

// make sure we don't expose any info if called directly
if (!defined('ABSPATH')) exit; // Exit if accessed directly

// Retrieve the filtered post types
$filtered_post_types = CIPFA_BaseController::cipfa_get_filtered_post_types();

// Gets the first filtered post type
$post_type = reset($filtered_post_types);

// Get taxonomies associated with this post type
$taxonomies = get_object_taxonomies($post_type->name, 'objects');
?>

<!-- Display import form -->
<div class="max-w-3xl mx-auto mt-28 p-8 bg-white rounded-lg shadow-lg">
   <h2 class="text-2xl mb-8 text-center font-semibold"><?php echo esc_html__('CSV Importer Plus for ACF', 'csv-importer-plus-for-acf') ?></h2>
   <form method="post" enctype="multipart/form-data" class="flex flex-col" id="csv-upload-form">
      <div class="mb-4 flex items-center">
         <label for="post_type_select" class="block text-sm font-semibold text-gray-600 mr-16"><?php echo esc_html__('Post Type:', 'csv-importer-plus-for-acf') ?></label>
         <select name="post_type" id="post_type_select" class="block w-1/2 p-2 border border-gray-300 rounded-md focus:outline-none focus:border-indigo-500">
            <?php foreach ($filtered_post_types as $post_type) : ?>
               <?php if ($post_type->name !== 'attachment') : ?>
                  <?php if ($post_type->name === 'product') : ?>
                     <optgroup label="Product">
                        <option value="product">Simple Products</option>
                        <option value="all_products_type" disabled style="color: #999;">Variable, Grouped & External Products - Pro Access</option>
                     <?php else : ?>
                     </optgroup>
                     <option value="<?php echo esc_attr($post_type->name); ?>"><?php echo esc_html($post_type->label); ?></option>
                  <?php endif; ?>
               <?php endif; ?>
            <?php endforeach; ?>
         </select>
      </div>
      <div class="mb-4 flex items-center">
         <label for="chunk-size" class="block text-sm font-semibold text-gray-600 mr-14"><?php echo esc_html__('Chunk Size:', 'csv-importer-plus-for-acf') ?></label>
         <select id="chunk-size" name="chunk_size" class="block  p-2 border border-gray-300 rounded-md focus:outline-none focus:border-indigo-500">
            <option value="<?php echo esc_attr(10); ?>"><?php echo esc_html__('10', 'csv-importer-plus-for-acf') ?></option>
            <option value="<?php echo esc_attr(20); ?>"><?php echo esc_html__('20', 'csv-importer-plus-for-acf') ?></option>
            <option value="<?php echo esc_attr(30); ?>"><?php echo esc_html__('30', 'csv-importer-plus-for-acf') ?></option>
            <option value="<?php echo esc_attr(40); ?>"><?php echo esc_html__('40', 'csv-importer-plus-for-acf') ?></option>
            <option value="<?php echo esc_attr(50); ?>"><?php echo esc_html__('50', 'csv-importer-plus-for-acf') ?></option>
            <option value="<?php echo esc_attr(60); ?>"><?php echo esc_html__('60', 'csv-importer-plus-for-acf') ?></option>
            <option value="<?php echo esc_attr(70); ?>"><?php echo esc_html__('70', 'csv-importer-plus-for-acf') ?></option>
            <option value="<?php echo esc_attr(80); ?>"><?php echo esc_html__('80', 'csv-importer-plus-for-acf') ?></option>
            <option value="<?php echo esc_attr(90); ?>"><?php echo esc_html__('90', 'csv-importer-plus-for-acf') ?></option>
            <option value="<?php echo esc_attr(100); ?>"><?php echo esc_html__('100', 'csv-importer-plus-for-acf') ?></option>
         </select>
      </div>
      <div class="mb-6 flex items-center">
         <label for="csv_file" class="block text-sm font-semibold text-gray-600 mr-6"><?php echo esc_html__('Upload CSV File:', 'csv-importer-plus-for-acf') ?></label>
         <input type="file" name="csv_file" id="csv-file" accept=".csv" />
      </div>
      <?php wp_nonce_field('cipfa_nonce', 'cipfa_nonce_field'); ?>
      <input type="hidden" name="step" value="2">
      <div class="mb-4 flex items-center">
         <label for="edit_existing" class="block text-sm font-semibold text-gray-600 mr-20"><?php echo esc_html__('Update', 'csv-importer-plus-for-acf') ?></label>
         <input type="checkbox" id="edit_existing" name="edit_existing" value="<?php echo esc_attr(1); ?>" class="mr-2">
         <span class="text-xs text-gray-500" id="id_column_text"><?php echo esc_html__('Check only to update existing posts. Must include post_id column in CSV.', 'csv-importer-plus-for-acf') ?></span>
      </div>
      <div class="mb-4 flex items-center">
         <label for="flush_cache" class="block text-sm font-semibold text-gray-600 mr-21"><?php echo esc_html__('Cache', 'csv-importer-plus-for-acf') ?></label>
         <input type="checkbox" id="flush_cache" name="flush_cache" value="<?php echo esc_attr(1); ?>" class="mr-2">
         <span class="text-xs text-gray-500" id="id_column_text"><?php echo esc_html__('Flush the WP cache after import.', 'csv-importer-plus-for-acf') ?></span>
      </div>
      <button type="submit" class="inline-flex items-center px-4 py-2 border border-transparent font-medium rounded-md text-white bg-gradient-to-br from-blue-600 to-purple-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 self-end text-lg" name="next"><?php echo esc_html__('Next', 'csv-importer-plus-for-acf') ?></button>
   </form>
</div>
<p class="text-center m-4">
   <?php esc_html_e('Please', 'csv-importer-plus-for-acf'); ?>
   <a href=" <?php echo esc_url('https://wordpress.org/support/plugin/csv-importer-plus-for-acf/reviews/#new-post'); ?>" target="_blank" title="<?php esc_attr_e('Rate the plugin', 'csv-importer-plus-for-acf'); ?>">
      <?php esc_html_e('Rate the plugin', 'csv-importer-plus-for-acf'); ?>
      <span class="rate-star">★★★★★</span>
   </a><?php esc_html_e('to help us spread the word. Thank you from the CSV Importer Plus for ACF team!', 'csv-importer-plus-for-acf'); ?>
</p>